==> client-java-api-7.0.0-sources.jar: io/kubernetes/client/openapi/models/V1beta1ControllerRevisionFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Boolean;

public interface V1beta1ControllerRevisionFluent<A extends V1beta1ControllerRevisionFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildData instead.
 * @return The buildable object.
 */
@Deprecated public RuntimeRawExtension getData();
    public RuntimeRawExtension buildData();
    public A withData(RuntimeRawExtension data);
    public Boolean hasData();
    public V1beta1ControllerRevisionFluent.DataNested<A> withNewData();
    public V1beta1ControllerRevisionFluent.DataNested<A> withNewDataLike(RuntimeRawExtension item);
    public V1beta1ControllerRevisionFluent.DataNested<A> editData();
    public V1beta1ControllerRevisionFluent.DataNested<A> editOrNewData();
    public V1beta1ControllerRevisionFluent.DataNested<A> editOrNewDataLike(RuntimeRawExtension item);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1ControllerRevisionFluent.MetadataNested<A> withNewMetadata();
    public V1beta1ControllerRevisionFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1ControllerRevisionFluent.MetadataNested<A> editMetadata();
    public V1beta1ControllerRevisionFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1ControllerRevisionFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public Long getRevision();
    public A withRevision(Long revision);
    public Boolean hasRevision();

    public interface DataNested<N> extends io.kubernetes.client.fluent.Nested<N>,RuntimeRawExtensionFluent<V1beta1ControllerRevisionFluent.DataNested<N>>{

        
    public N and();    public N endData();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1ControllerRevisionFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-9.0.2-sources.jar: io/kubernetes/client/openapi/models/V1beta1ControllerRevisionFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;

public interface V1beta1ControllerRevisionFluent<A extends V1beta1ControllerRevisionFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public Object getData();
    public A withData(Object data);
    public Boolean hasData();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1ControllerRevisionFluent.MetadataNested<A> withNewMetadata();
    public V1beta1ControllerRevisionFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1ControllerRevisionFluent.MetadataNested<A> editMetadata();
    public V1beta1ControllerRevisionFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1ControllerRevisionFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public Long getRevision();
    public A withRevision(Long revision);
    public Boolean hasRevision();

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1ControllerRevisionFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
